@@ -1,9 +1,11 @@
 package Perinci::Examples::Bin::Any;
 
-our $DATE = '2021-01-30'; # DATE
-our $VERSION = '0.071'; # VERSION
+use strict;
 
-use 5.010001;
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-03-08'; # DATE
+our $DIST = 'Perinci-Examples-Bin-Any'; # DIST
+our $VERSION = '0.072'; # VERSION
 
 1;
 # ABSTRACT: Perinci example scripts (using Perinci::CmdLine::Any)
@@ -20,7 +22,7 @@ Perinci::Examples::Bin::Any - Perinci example scripts (using Perinci::CmdLine::A
 
 =head1 VERSION
 
-This document describes version 0.071 of Perinci::Examples::Bin::Any (from Perl distribution Perinci-Examples-Bin-Any), released on 2021-01-30.
+This document describes version 0.072 of Perinci::Examples::Bin::Any (from Perl distribution Perinci-Examples-Bin-Any), released on 2022-03-08.
 
 =head1 DESCRIPTION
 
@@ -35,14 +37,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples-Bin-Any>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Any>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Perinci::Examples::Bin::Classic>
@@ -53,11 +47,42 @@ L<Perinci::Examples::Bin::Lite>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Any>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
